from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, String, File

Shapeknots_Smp_V0_1_0 = CommandToolBuilder(tool="ShapeKnots_smp", base_command=["ShapeKnots-smp"], inputs=[ToolInput(tag="in_constraint", input_type=Boolean(optional=True), prefix="--constraint", doc=InputDocumentation(doc="Specify a constraints file to be applied.\nDefault is to have no constraints applied.")), ToolInput(tag="in_dms", input_type=Boolean(optional=True), prefix="--DMS", doc=InputDocumentation(doc="Specify a DMS constraints file to be applied. These constraints are\npseudoenergy constraints.\nDefault is to have no constraints applied.")), ToolInput(tag="in_d_shape", input_type=Boolean(optional=True), prefix="--DSHAPE", doc=InputDocumentation(doc="Specify a differential SHAPE restraints file to be applied. These\nconstraints are pseudoenergy restraints.\nDefault is to have no restraints applied.")), ToolInput(tag="in_d_shape_slope", input_type=Boolean(optional=True), prefix="--DSHAPEslope", doc=InputDocumentation(doc="Specify a slope used with differential SHAPE restraints.\nDefault is 2.11 kcal/mol.")), ToolInput(tag="in_double_offset", input_type=Boolean(optional=True), prefix="--doubleOffset", doc=InputDocumentation(doc="Specify a double-stranded offset file, which adds energy bonuses to\nparticular double-stranded nucleotides.\nDefault is to have no double-stranded offset specified.")), ToolInput(tag="in_i_maximum", input_type=Boolean(optional=True), prefix="--IMaximum", doc=InputDocumentation(doc="Specify a maximum number of internally generated structures for each call\nof the dynamic programming algorithm. Note that suboptimal structures are\ngenerated until either the maximum number of structures is reached or the\nmaximum percent difference is reached (below).\nThis is not the maximum number of structures provided to the user, which is\ncontrolled by –m, -M, --maximum.\nDefault is 100 structures.")), ToolInput(tag="in_i_percent", input_type=Boolean(optional=True), prefix="--IPercent", doc=InputDocumentation(doc="Specify a maximum percent difference in folding free energy change for\ninternally generated suboptimal structures for each call of the dynamic\nprogramming algorithm. For example, 20 would indicate 20%. This is not the\nmaximum percent difference in energy for structures provided to the user,\nwhich is controlled by –p, -P, --percent.\nDefault is 20%.")), ToolInput(tag="in_i_window", input_type=Boolean(optional=True), prefix="--IWindow", doc=InputDocumentation(doc="Specify a window size for the internally generated suboptimal structures\nfor each call of the dynamic programming algorithm.\nThis is not the window for structures provided to the user, which is\ncontrolled by –w, -W, --window.\nDefault is determined by the length of the sequence.")), ToolInput(tag="in_maximum", input_type=Boolean(optional=True), prefix="--maximum", doc=InputDocumentation(doc="Specify a maximum number of structures to be outputted. Note that\nsuboptimal structures are generated until either the maximum number of\nstructures is reached or the maximum percent difference is reached\n(below).\nDefault is 20 structures.")), ToolInput(tag="in_percent", input_type=Boolean(optional=True), prefix="--percent", doc=InputDocumentation(doc="Specify a maximum percent difference in folding free energy change for\ngenerating suboptimal structures in the output. For example, 10 would\nindicate 10%.\nDefault is 10%.")), ToolInput(tag="in_penalty_one", input_type=Boolean(optional=True), prefix="--Penalty1", doc=InputDocumentation(doc="Specify a pseudoknot penalty P1.\nDefault is 0.35 kcal/mol.")), ToolInput(tag="in_penalty_two", input_type=Boolean(optional=True), prefix="--Penalty2", doc=InputDocumentation(doc="Specify a pseudoknot penalty P2.\nDefault is 0.65 kcal/mol.")), ToolInput(tag="in_pseudo_knotted_helices", input_type=Boolean(optional=True), prefix="--PseudoknottedHelices", doc=InputDocumentation(doc="Specify maximum number of helices to be processed.\nDefault is 100 helices.")), ToolInput(tag="in_shape", input_type=Boolean(optional=True), prefix="--SHAPE", doc=InputDocumentation(doc="Specify a SHAPE restraints file to be applied. These restraints\nspecifically use SHAPE pseudoenergy restraints.\nDefault is no SHAPE restraint file specified.")), ToolInput(tag="in_shape_intercept", input_type=Boolean(optional=True), prefix="--SHAPEintercept", doc=InputDocumentation(doc="Specify an intercept used with SHAPE restraints.\nDefault is -0.6 kcal/mol.")), ToolInput(tag="in_shape_slope", input_type=Boolean(optional=True), prefix="--SHAPEslope", doc=InputDocumentation(doc="Specify an slope used with SHAPE restraints.\nDefault is 1.8 kcal/mol.")), ToolInput(tag="in_single_offset", input_type=Boolean(optional=True), prefix="--singleOffset", doc=InputDocumentation(doc="Specify a single-stranded offset file, which adds energy bonuses to\nparticular single-stranded nucleotides.\nDefault is to have no single-stranded offset specified.")), ToolInput(tag="in_window", input_type=Boolean(optional=True), prefix="--window", doc=InputDocumentation(doc="Specify a window size for outputted suboptimal structures.\nDefault is determined by the length of the sequence.")), ToolInput(tag="in_warnings", input_type=Boolean(optional=True), prefix="--warnings", doc=InputDocumentation(doc="Set the behavior for non-critical warnings (e.g. related to invalid\nnucleotide positions or duplicate data points in SHAPE data). Valid values\nare:\n* on  -- Warnings are written to standard output. (default)\n* err -- Warnings are sent to STDERR. This can be used in automated scripts\netc to detect problems.\n* off -- Do not display warnings at all (not recommended).")), ToolInput(tag="in_experimental_pair_bonus", input_type=Boolean(optional=True), prefix="--experimentalPairBonus", doc=InputDocumentation(doc="Input text file with bonuses (in kcal) as a matrix. As with SHAPE, bonuses\nwill be applied twice to internal base pairs, once to edge base pairs, and\nnot at all to single stranded regions.\nDefault is no experimental pair bonus file specified.")), ToolInput(tag="in_xo", input_type=Boolean(optional=True), prefix="-xo", doc=InputDocumentation(doc="Specify an intercept (overall offset) to use with the 2D experimental pair\nbonus file.\nDefault is 0.0 (no change to input bonuses).")), ToolInput(tag="in_xs", input_type=Boolean(optional=True), prefix="-xs", doc=InputDocumentation(doc="Specify a number to multiply the experimental pair bonus matrix by.\nDefault is 1.0 (no change to input bonuses).\n")), ToolInput(tag="in_shape_knots", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_seq_file", input_type=File(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_ct_file", input_type=File(), position=2, doc=InputDocumentation(doc=""))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Shapeknots_Smp_V0_1_0().translate("wdl", allow_empty_container=True)

